package com.businessrefinery.barcode.linear.demo;

import com.businessrefinery.barcode.linear.Linear;

import java.applet.Applet;
import java.awt.*;


public class DemoApplet extends Applet
{

    public Linear linear;
    public boolean isStandalone;

    public DemoApplet()
    {
        linear = null;
        isStandalone = true;
        setLayout(new BorderLayout());
    }

    public void start()
    {
        linear.autoSize = true;
        linear.paint(getGraphics());
    }

    public void refresh()
    {
        linear.paint(linear.getGraphics());
        paintAll(getGraphics());
    }

    public void init()
    {
        if(linear == null)
        {
            linear = new Linear();
        }
        add("Center", linear);

        initParam("DATA");
        initParam("BARCODE_TYPE");
        initParam("ADD_CHECK_DIGIT");
        initParam("ADD_CHECK_DIGIT_TO_TEXT");
        initParam("CODE128_CHAR_SET");
        initParam("EAN_UPC_SUPPLEMENT");
        initParam("UPCE_SYSTEM");
        initParam("ROTATE_ANGLE");
        initParam("X");
        initParam("N");
        initParam("WHITE_BAR_INCREASE");
        initParam("BAR_HEIGHT");
        initParam("BACKGROUND_COLOR");
        initParam("BAR_COLOR");
        initParam("TEXT_COLOR");
        initParam("TEXT_FONT");
        initParam("TEXT_MARGIN");
        initParam("BEARER_BARS");
        initParam("CHARACTER_GROUPING");

    }

    private void initParam(String para)
    {
        String s1 = getStringParam(para, "");
        if(s1.length() > 0)
        {
            setParameter(para, s1);
        }
    }

    public void setParameter(String para, String value)
    {
        if(value == null)
        {
            return;
        }
        if(para.compareTo("DATA") == 0)
        {
            linear.setDataToEncode(value);
        }
        if(para.compareTo("BARCODE_TYPE") == 0)
        {
            if(value.compareTo("CODE39") == 0)
            {
                linear.barcodeType = Linear.CODE39;
            }
            if(value.compareTo("CODE39EXT") == 0)
            {
                linear.barcodeType = Linear.CODE39EXT;
            }
            if(value.compareTo("INTERLEAVED25") == 0)
            {
                linear.barcodeType = Linear.INTERLEAVED25;
            }
            if(value.compareTo("CODE11") == 0)
            {
                linear.barcodeType = Linear.CODE11;
            }
            if(value.compareTo("CODABAR") == 0)
            {
                linear.barcodeType = Linear.CODABAR;
            }
            if(value.compareTo("MSI") == 0)
            {
                linear.barcodeType = Linear.MSI;
            }
            if(value.compareTo("UPCA") == 0)
            {
                linear.barcodeType = Linear.UPCA;
            }
            if(value.compareTo("IND25") == 0)
            {
                linear.barcodeType = Linear.IND25;
            }
            if(value.compareTo("MAT25") == 0)
            {
                linear.barcodeType = Linear.MAT25;
            }
            if(value.compareTo("CODE93") == 0)
            {
                linear.barcodeType = Linear.CODE93;
            }
            if(value.compareTo("EAN13") == 0)
            {
                linear.barcodeType = Linear.EAN13;
            }
            if(value.compareTo("EAN8") == 0)
            {
                linear.barcodeType = Linear.EAN8;
            }
            if(value.compareTo("UPCE") == 0)
            {
                linear.barcodeType = Linear.UPCE;
            }
            if(value.compareTo("CODE128") == 0)
            {
                linear.barcodeType = Linear.CODE128;
            }
            if(value.compareTo("CODE93EXT") == 0)
            {
                linear.barcodeType = Linear.CODE39EXT;
            }
            if(value.compareTo("POSTNET") == 0)
            {
                linear.barcodeType = Linear.POSTNET;
            }
            if(value.compareTo("PLANET") == 0)
            {
                linear.barcodeType = Linear.PLANET;
            }
            if(value.compareTo("UCC128") == 0)
            {
                linear.barcodeType = Linear.UCC128;
            }
            if(value.compareTo("ONECODE") == 0)
            {
                linear.barcodeType = Linear.ONECODE;
            }
        }
        if(para.compareTo("ADD_CHECK_DIGIT") == 0)
        {
            linear.checkCharacter = value.compareTo("Y") == 0;
        }
        if(para.compareTo("ADD_CHECK_DIGIT_TO_TEXT") == 0)
        {
            linear.checkCharacterInText = value.compareTo("Y") == 0;
        }
        if(para.compareTo("CODE128_CHAR_SET") == 0)
        {
            linear.Code128Set = (value + "B").charAt(0);
        }
        if(para.compareTo("EAN_UPC_SUPPLEMENT") == 0)
        {
            linear.UPCEANSupplement2 = false;
            linear.UPCEANSupplement5 = false;
            if(value.compareTo("2") == 0)
            {
                linear.UPCEANSupplement2 = true;
            }
            if(value.compareTo("5") == 0)
            {
                linear.UPCEANSupplement5 = true;
            }
        }
        if(para.compareTo("UPCE_SYSTEM") == 0)
        {
            linear.UPCESystem = (new String(value + "1")).charAt(0);
        }
        if(para.compareTo("ROTATE_ANGLE") == 0)
        {
            linear.setRotationAngle((int)(new Double(value)).doubleValue());
        }
        if(para.compareTo("X") == 0)
        {
            linear.X = (new Double(value)).doubleValue();
        }
        if(para.compareTo("N") == 0)
        {
            linear.N = (new Double(value)).doubleValue();
        }
        if(para.compareTo("WHITE_BAR_INCREASE") == 0)
        {
            linear.whiteBarIncrease = (new Float(value)).floatValue();
        }
        if(para.compareTo("BAR_HEIGHT") == 0)
        {
            linear.barHeightCM = (new Double(value)).doubleValue();
        }
        if(para.compareTo("BACKGROUND_COLOR") == 0)
        {
            linear.backgroundColor = convertColor(value);
        }
        if(para.compareTo("BAR_COLOR") == 0)
        {
            linear.barColor = convertColor(value);
        }
        if(para.compareTo("TEXT_COLOR") == 0)
        {
            linear.textFontColor = convertColor(value);
        }
        if(para.compareTo("TEXT_FONT") == 0)
        {
            linear.textFont = convertFont(value);
        }
        if(para.compareTo("TEXT_MARGIN") == 0)
        {
            linear.textMarginCM = (new Double(value)).doubleValue();
        }
        if(para.compareTo("BEARERBAR_HORIZONTAL") == 0)
        {
            linear.bearerBarHori = (new Double(value)).doubleValue();
        }
        if(para.compareTo("BEARERBAR_VERTICAL") == 0)
        {
            linear.bearerBarVert = (new Double(value)).doubleValue();
        }
        if(para.compareTo("CHARACTER_GROUPING") == 0)
        {
            linear.valSpliceText = (new Integer(value)).intValue();
        }






        /*
        if(s.compareTo("SUPPLEMENT_CODE") == 0)
        {
            linear.supplement = s1;
        }
        if(s.compareTo("SUPPLEMENT_SEPARATION") == 0)
        {
            linear.supSeparationCM = (new Double(s1)).doubleValue();
        }
        if(s.compareTo("SUPPLEMENT_HEIGHT") == 0)
        {
            linear.supHeight = (new Double(s1)).doubleValue();
        }


        if(s.compareTo("POSTNET_TALL") == 0)
        {
            linear.postnetHeightTallBar = (int)(new Double(s1)).doubleValue();
        }
        if(s.compareTo("POSTNET_SHORT") == 0)
        {
            linear.postnetHeightShortBar = (int)(new Double(s1)).doubleValue();
        }

        if(s.compareTo("LEFT_MARGIN") == 0)
        {
            linear.leftMarginCM = (new Double(s1)).doubleValue();
        }
        if(s.compareTo("TOP_MARGIN") == 0)
        {
            linear.topMarginCM = (new Double(s1)).doubleValue();
        }



        if(s.compareTo("GUARDBARS") == 0)
        {
            linear.guardBars = s1.compareTo("Y") == 0;
        }

        if(s.compareTo("CODABAR_START") == 0)
        {
            linear.CODABARStartChar = (new String(s1 + "A")).charAt(0);
        }
        if(s.compareTo("CODABAR_STOP") == 0)
        {
            linear.CODABARStopChar = (new String(s1 + "A")).charAt(0);
        }

        if(s.compareTo("H") == 0)
        {
            linear.H = (new Double(s1)).doubleValue();
        }

        if(s.compareTo("ST") == 0)
        {
            linear.showText = s1.compareTo("Y") == 0;
        }
        if(s.compareTo("PT") == 0)
        {
            linear.processTilde = s1.toUpperCase().compareTo("Y") == 0;
        }
        */



    }

    public Color convertColor(String s)
    {
        if(s.compareTo("NULL") == 0)
        {
            return null;
        }
        if(s.compareTo("RED") == 0)
        {
            return Color.red;
        }
        if(s.compareTo("BLACK") == 0)
        {
            return Color.black;
        }
        if(s.compareTo("BLUE") == 0)
        {
            return Color.blue;
        }
        if(s.compareTo("CYAN") == 0)
        {
            return Color.cyan;
        }
        if(s.compareTo("DARKGRAY") == 0)
        {
            return Color.darkGray;
        }
        if(s.compareTo("GRAY") == 0)
        {
            return Color.gray;
        }
        if(s.compareTo("GREEN") == 0)
        {
            return Color.green;
        }
        if(s.compareTo("LIGHTGRAY") == 0)
        {
            return Color.lightGray;
        }
        if(s.compareTo("MAGENTA") == 0)
        {
            return Color.magenta;
        }
        if(s.compareTo("ORANGE") == 0)
        {
            return Color.orange;
        }
        if(s.compareTo("PINK") == 0)
        {
            return Color.pink;
        }
        if(s.compareTo("WHITE") == 0)
        {
            return Color.white;
        }
        if(s.compareTo("YELLOW") == 0)
        {
            return Color.yellow;
        }
        try {
            return Color.decode(s);
        } catch (Exception e) {
            return Color.black;
        }
    }

    public Font convertFont(String s)
    {
        String as[];
        byte byte0;
        as = convertList(s);
        if(as == null)
        {
            return null;
        }
        if(as.length < 3)
        {
            return null;
        }
        byte0 = 0;
        if(as[1].compareTo("BOLD") == 0)
        {
            byte0 = 1;
        }
        if(as[1].compareTo("ITALIC") == 0)
        {
            byte0 = 2;
        }
        try {
            return new Font(as[0], byte0, (new Integer(as[2])).intValue());
        } catch (Exception e) {
            return null;
        }
    }

    protected String getStringParam(String s, String s1)
    {
        return getParameterValue(s, s1);
    }

    private String getParameterValue(String paraName, String defaultValue)
    {
        if(isStandalone)
        {
            return defaultValue;
        }
        if(getParameter(paraName) != null)
        {
            return getParameter(paraName);
        }
        else
        {
            return defaultValue;
        }
    }

    private String[] convertList(String s)
    {
        String as[] = new String[500];
        int i = 0;
        for(int j = s.indexOf("|"); j >= 0; j = s.indexOf("|"))
        {
            as[i++] = s.substring(0, j);
            s = s.substring(j + 1, s.length());
        }

        if(s.compareTo("") != 0)
        {
            as[i++] = s;
        }
        if(i == 0)
        {
            return null;
        }
        String as1[] = new String[i];
        for(int k = 0; k < i; k++)
        {
            as1[k] = as[k];
        }

        return as1;
    }

    private Integer getIntParam(String s, Integer integer)
    {
        String s1 = getParameterValue(s, "");
        if(s1.compareTo("") == 0)
        {
            return integer;
        }

        try {
            return new Integer(s1);
        } catch (Exception e) {
            return integer;
        }

    }

    private Double getDoubleParam(String s, Double double1)
    {
        String s1 = getParameterValue(s, "");
        if(s1.compareTo("") == 0)
        {
            return double1;
        }
        try {
            return new Double(s1);
        } catch (Exception e) {
            return double1;
        }
    }
}

